
# Slot: enabled by


The gene product, gene, or complex that catalyzes the reaction

URI: [biolink:molecular_activity_enabled_by](https://w3id.org/biolink/vocab/molecular_activity_enabled_by)


## Domain and Range

[MolecularActivity](MolecularActivity.md) &#8594;  <sub>0..\*</sub> [MacromolecularMachineMixin](MacromolecularMachineMixin.md)

## Parents

 *  is_a: [enabled by](enabled_by.md)

## Children


## Used by

 * [MolecularActivity](MolecularActivity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002333 |

